// java wrapper for vtkCommand object
//

package vtk;
import vtk.*;

public class vtkCommand extends vtkObjectBase
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void UnRegister_2();
  public void UnRegister()
    { UnRegister_2(); }

  private native void UnRegister_3(vtkObjectBase id0);
  public void UnRegister(vtkObjectBase id0)
    { UnRegister_3(id0); }

  private native String GetStringFromEventId_4(int id0);
  public String GetStringFromEventId(int id0)
    { return GetStringFromEventId_4(id0); }

  private native int GetEventIdFromString_5(String id0);
  public int GetEventIdFromString(String id0)
    { return GetEventIdFromString_5(id0); }

  private native boolean EventHasData_6(int id0);
  public boolean EventHasData(int id0)
    { return EventHasData_6(id0); }

  private native void SetAbortFlag_7(int id0);
  public void SetAbortFlag(int id0)
    { SetAbortFlag_7(id0); }

  private native int GetAbortFlag_8();
  public int GetAbortFlag()
    { return GetAbortFlag_8(); }

  private native void AbortFlagOn_9();
  public void AbortFlagOn()
    { AbortFlagOn_9(); }

  private native void AbortFlagOff_10();
  public void AbortFlagOff()
    { AbortFlagOff_10(); }

  private native void SetPassiveObserver_11(int id0);
  public void SetPassiveObserver(int id0)
    { SetPassiveObserver_11(id0); }

  private native int GetPassiveObserver_12();
  public int GetPassiveObserver()
    { return GetPassiveObserver_12(); }

  private native void PassiveObserverOn_13();
  public void PassiveObserverOn()
    { PassiveObserverOn_13(); }

  private native void PassiveObserverOff_14();
  public void PassiveObserverOff()
    { PassiveObserverOff_14(); }

  public vtkCommand() { super(); }

  public vtkCommand(long id) { super(id); }

}
